/****************************************************************************
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 *~                             IR Kernel                                    ~
 *~                         Copyright(C) 1993                                ~
 *~                       Software Kinetics Ltd.                             ~
 *~                        All Rights Reserved                               ~
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 * Copyright Software Kinetics Ltd.
 * 
 * Software Kinetics Ltd. has granted a licence of this software to
 * National Library of Canada.
 *
 * The National Library of Canada grants to the user a royalty-free
 * non-exclusive licence in perpetuity to use, modify, improve,
 * reproduce and sell the software.
 *
 * The software is provided to the user "as is" without warranty of
 * any kind.  Neither Software Kinetics Ltd. nor the National Library
 * of Canada warrants,guarantees or makes any representation regarding
 * the use, or the results of the use of the software in terms of
 * accuracy,reliability, or otherwise.  The entire risk as results and
 * performance of the software is assumed by the user. Neither
 * Software Kinetics Ltd. nor the National Library of Canada shall be
 * liable for any direct, indirect, consequential or incidental
 * damages arising out the use of software.
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ 
 *
 * Program: cspabort.c
 *
 * Purpose: This function closes the client and QRM ports and removes
 *          the current association from the association list by calling
 *          A_abort.
 *
 * Invocation:
 *
 * Input Arguments:
 *
 * Output/Exit Values: None
 *
 * Functions used: cs_P_pabort_request()
 *
 * Version: Date:   93/05/12
 *          Name:   Benjamin Yen
 *          Reason: First Draft of IR Target Kernel
 *
 * Reference: IR KERNEL - TARGET PRELIMINARY SOFTWARE DESIGN DOCUMENT
 *            IR KERNEL - TARGET SOFTWARE DETAIL DESIGN DOCUMENT
 *            IR KERNEL - INTERFACE REQUIREMENTS SPECIFICATION
 *            OSI - ANSI Z39.50 DOCUMENTATION
 *
 * Notes:
 *
 * $Id: cspabort.c,v 1.1 1993/11/01 17:03:51 irsuprt Exp irsuprt $
 * $Log: cspabort.c,v $
 * Revision 1.1  1993/11/01  17:03:51  irsuprt
 * Initial revision
 *
 *
 *****************************************************************************/

#include <stdio.h>
#include "ir.h"
#include "irerror.h"
#include "irconst.h"
#include "irassoc.h"
#include "acse.h"

/*****************************************************************************
 *
 * Function: cs_P_pabort_request()
 *
 * Purpose: This function closes the client and QRM ports and removes
 *          the current association from the association list by calling
 *          A_abort.
 *
 * Input Arguments:
 *          assoc_list - pointer to the association list
 *          assocId    - pointer to the current association
 *
 * Return values:   SUCCESS - operation was completed successfully
 *                  FAILED  - operation failed
 *
 * Output Arguments:
 *
 * External Variables:
 *
 * Function used:
 *          A_abort()
 *
 * Algorithm:
 *
 * Version: Date:   93/05/12
 *          Name:   Benjamin Yen
 *          Reason: First Draft of IR Target Kernel
 *
 * Reference: IR KERNEL - TARGET PRELIMINARY SOFTWARE DESIGN DOCUMENT
 *            IR KERNEL - TARGET SOFTWARE DETAIL DESIGN DOCUMENT
 *            IR KERNEL - INTERFACE REQUIREMENTS SPECIFICATION
 *            OSI - ANSI Z39.50 DOCUMENTATION
 *
 * Notes:
 *
 ****************************************************************************/

int
cs_P_pabort_request(assoc_list, assocId)
    struct queue_struct **assoc_list;
    struct assoc_struct **assocId;
{

#ifdef DEBUG_LEVEL1
    fprintf(DEBUG_FILE1, "Calling cs_P_pabort_request ...\n");
#endif

	return(A_abort(assoc_list, assocId));
}
