/****************************************************************************
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 *~                             IR Kernel                                    ~
 *~                         Copyright(C) 1993                                ~
 *~                       Software Kinetics Ltd.                             ~
 *~                        All Rights Reserved                               ~
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 * Copyright Software Kinetics Ltd.
 * 
 * Software Kinetics Ltd. has granted a licence of this software to
 * National Library of Canada.
 *
 * The National Library of Canada grants to the user a royalty-free
 * non-exclusive licence in perpetuity to use, modify, improve,
 * reproduce and sell the software.
 *
 * The software is provided to the user "as is" without warranty of
 * any kind.  Neither Software Kinetics Ltd. nor the National Library
 * of Canada warrants,guarantees or makes any representation regarding
 * the use, or the results of the use of the software in terms of
 * accuracy,reliability, or otherwise.  The entire risk as results and
 * performance of the software is assumed by the user. Neither
 * Software Kinetics Ltd. nor the National Library of Canada shall be
 * liable for any direct, indirect, consequential or incidental
 * damages arising out the use of software.
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ 
 *
 * Program: cspdatar.c
 *
 * Purpose: This file contains functions to encode the APDU.
 *
 * Invocation:
 *
 * Input Arguments:
 *
 * Output/Exit Values: None
 *
 * Functions used:  cs_Pdata_request()
 *
 * Version: Date:   93/05/12
 *          Name:   Jim Saunders & Benjamin Yen
 *          Reason: First Draft of IR Target Kernel
 *
 * Reference: IR KERNEL - TARGET PRELIMINARY SOFTWARE DESIGN DOCUMENT
 *            IR KERNEL - TARGET SOFTWARE DETAIL DESIGN DOCUMENT
 *            IR KERNEL - INTERFACE REQUIREMENTS SPECIFICATION
 *            OSI - ANSI Z39.50 DOCUMENTATION
 *
 * Notes:
 *
 * $Id: cspdatar.c,v 1.1 1993/11/01 17:03:51 irsuprt Exp irsuprt $
 * $Log: cspdatar.c,v $
 * Revision 1.1  1993/11/01  17:03:51  irsuprt
 * Initial revision
 *
 *
 *****************************************************************************/

#include <stdio.h>
#include "ir.h"
#include "irconst.h"
#include "irerror.h"
#include "asn_incl.h"

/*****************************************************************************
 *
 * Function: cs_Pdata_request
 *
 * Purpose: This function encodes the PDU_ptr (PDU) and stored in BERRecord
 *          (APDU).
 *
 * Input Arguments:      PDU_ptr   - pointer to APDU to be encoded
 *
 * Return values:        SUCCESS   - APDU has been encoded successfully
 *                       FAILED    - APDU encoding has failed
 *
 * Output Arguments: BERRecord - BER encoded record
 *                   encoded_length - the size of the encoded APDU/BER record
 *
 * Function used:
 *                  SBufInstallData()
 *                  SBufResetInWriteRvsMode()
 *                  BEncAPDU()
 *
 * Version: Date:   93/05/12
 *          Name:   Jim Saunders & Benjamin Yen
 *          Reason: First Draft of IR Target Kernel
 *
 * References:
 *
 * Notes:
 *
 ****************************************************************************/

int
cs_Pdata_request(PDU_ptr, BERRecord, encoded_length)
    APDU *PDU_ptr;
    char **BERRecord;
    int *encoded_length;
{

    SBuf buf;

#ifdef DEBUG_LEVEL1
    fprintf(DEBUG_FILE1, "Calling cs_Pdata_request ...\n");
#endif

    (*BERRecord) = (char *) malloc(MAXMESSAGESIZE * 2);
    SBufInstallData(&buf, (*BERRecord), MAXMESSAGESIZE * 2);
    SBufResetInWriteRvsMode(&buf);

    *encoded_length = BEncAPDU(&buf, PDU_ptr);

	if (SBufWriteError(&buf))
	{
		display_error("KERNEL", ERR_ENCODE_APDU, -1);
		return(FAILED);
	}
	else
    {
        memcpy((*BERRecord), SBufDataPtr(&buf), SBufDataLen(&buf));
        return (SUCCESS);
    }

}                                /* end of procedure cs_Pdata_request */
